utils::globalVariables(
  c(
    "value",
    "name",
    "base",
    "pckg_origin",
    "n",
    "pckg",
    "func",
    "total",
    "count",
    "desc",
    "Function",
    "Package",
    "packfun",
    "pckg_preferred",
    "pckgx"
  )
)
